@@ -34,6 +34,8 @@ from je_api_testka.utils.xml.xml_file.xml_file import XMLParser
 from je_api_testka.utils.xml.xml_file.xml_file import reformat_xml_file
 # Mock server
 from je_api_testka.utils.mock_server.flask_mock_server import flask_mock_server_instance
+# Flask
+from flask import request, redirect
 
 __all__ = ["test_api_method",
            "add_command_to_executor",
@@ -44,5 +46,6 @@ __all__ = ["test_api_method",
            "start_apitestka_socket_server",
            "test_record_instance", "dict_to_elements_tree", "elements_tree_to_dict",
            "XMLParser", "reformat_xml_file", "generate_xml", "generate_xml_report",
-           "callback_executor", "create_project_dir", "flask_mock_server_instance"
+           "callback_executor", "create_project_dir", "flask_mock_server_instance",
+           "request", "redirect"
            ]
