@@ -3,6 +3,7 @@ import argparse
 import json
 import sys
 
+from je_api_testka import create_project_dir
 from je_api_testka.utils.exception.exception_tags import argparse_get_wrong_data
 from je_api_testka.utils.exception.exceptions import APITesterExecuteException
 from je_api_testka.utils.executor.action_executor import execute_action
@@ -28,13 +29,27 @@ if __name__ == "__main__":
         argparse_event_dict = {
             "execute_file": preprocess_read_json_file_execute_action,
             "execute_dir": preprocess_read_json_files_execute_files,
-            "execute_str": preprocess_read_str_execute_action
+            "execute_str": preprocess_read_str_execute_action,
+            "create_project": create_project_dir
         }
 
         parser = argparse.ArgumentParser()
-        parser.add_argument("-e", "--execute_file", type=str, help="choose action file to execute")
-        parser.add_argument("-d", "--execute_dir", type=str, help="choose dir include action file to execute")
-        parser.add_argument("--execute_str", type=str, help="execute json str")
+        parser.add_argument(
+            "-e", "--execute_file",
+            type=str, help="choose action file to execute"
+        )
+        parser.add_argument(
+            "-d", "--execute_dir",
+            type=str, help="choose dir include action file to execute"
+        )
+        parser.add_argument(
+            "--execute_str",
+            type=str, help="execute json str"
+        )
+        parser.add_argument(
+            "-c", "--create_project",
+            type=str, help="create project with template"
+        )
         args = parser.parse_args()
         args = vars(args)
         for key, value in args.items():
