@@ -147,3 +147,12 @@ class APIJsonReportException(APITesterException):
 
 class APIAddCommandException(APITesterException):
     pass
+
+
+# Execute callback
+class CallbackExecutorException(APITesterException):
+    pass
+
+
+class MockServerException(APITesterException):
+    pass
