@@ -10,22 +10,34 @@ class FlaskMockServer(object):
     pass
 
     def __init__(self, host, port):
+        """
+        :param host: mock server's host name
+        :param port: mock server's port
+        """
         self.app = Flask(__name__)
         self.host = host
         self.port = port
 
-    
-    def api_testka_index_function(self):
+    @classmethod
+    def api_testka_index_function(cls) -> str:
         return "APITestka main index"
 
-    def add_router(self, rule_and_function_dict: dict, **kwargs):
+    def add_router(self, rule_and_function_dict: dict, **kwargs) -> None:
+        """
+        :param rule_and_function_dict: dict include {"rule(path): function"}
+        :param kwargs: use to set methods or another param
+        :return:
+        """
         for rule, function in rule_and_function_dict.items():
             if isinstance(rule, str) and isinstance(function, typing.Callable):
                 self.app.route(rule, **kwargs)(function)
             else:
                 raise MockServerException(get_bad_api_router_setting)
 
-    def start_mock_server(self):
+    def start_mock_server(self) -> None:
+        """
+        start mock server
+        """
         self.add_router(
             {"/": self.api_testka_index_function},
             methods=["GET"]
